@@ -1,4 +1,6 @@
 c            photo electric effect const.
+       integer maxNoOfShells
+       parameter(maxNoOfShells=16)
        structure /photoE/
           real*8 b0        
           real*8 b1
@@ -12,5 +14,7 @@ c            photo electric effect const.
           real*8 cr     ! correction factor for low Z
                         ! cross-section at Eg=0.2 MeV
                         ! this is multiplied to old cross-section
+	  real*4 shellE(maxNoOfShells)  ! from v8.70
+	  integer noOfShells
        end structure
   
