@@ -33,6 +33,7 @@ c          common variables used in tracking ptcls.
         record /epPos/ FirstInt !  to keep first int. pos.
         record /ep3Vec/ Bfield   !  Bfield.x, y, z  the B in  Tesla
                                 !    in local coordinate 
+        real*8   pathInB        !  total path length in B for a particle 
         record /ep3Vec/ Efield   !  Efiled.x, y, z  the E in V/m
                                 !   local coordinate.
         real*8 SumDe       !  sum  of all energy deposit
@@ -49,7 +50,7 @@ c          common variables used in tracking ptcls.
 c
        common /ZepTrackv/ Media, Incident, cTrack, Move, 
      *  Bfield, Efield,
-     *  FirstInt, MaxPath, Upsilon, Xai,
+     *  FirstInt, MaxPath, Upsilon, Xai,  pathInB,
      *  Beta, Tcoefx, Tminx,  SumDe, Cn, MediaNo,
      *  Ethin, Firsti, FirstC, Bndryerr
 
